m4-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Changes to m4/m4/m4module.h,v


From: Eric Blake
Subject: Changes to m4/m4/m4module.h,v
Date: Mon, 28 Aug 2006 12:48:55 +0000

CVSROOT:        /sources/m4
Module name:    m4
Changes by:     Eric Blake <ericb>      06/08/28 12:48:54

Index: m4/m4module.h
===================================================================
RCS file: /sources/m4/m4/m4/m4module.h,v
retrieving revision 1.80
retrieving revision 1.81
diff -u -b -r1.80 -r1.81
--- m4/m4module.h       25 Aug 2006 22:06:42 -0000      1.80
+++ m4/m4module.h       28 Aug 2006 12:48:54 -0000      1.81
@@ -44,11 +44,15 @@
 
 /* The value of m4_builtin flags is built from these:  */
 enum {
-  /* set if macro can handle non-text tokens, such as builtin macro tokens */
+  /* Set if macro can handle non-text tokens, such as builtin macro
+     tokens; if clear, non-text tokens are flattened to the empty
+     string before invoking the builtin.  */
   M4_BUILTIN_GROKS_MACRO       = (1 << 0),
-  /* set if macro should only be recognized with arguments */
+  /* Set if macro should only be recognized with arguments; may only
+     be set if min_args is nonzero.  */
   M4_BUILTIN_BLIND             = (1 << 1),
-  /* set if macro has side effects even when there are too few arguments */
+  /* set if macro has side effects even when there are too few
+     arguments; may only be set if min_args is nonzero.  */
   M4_BUILTIN_SIDE_EFFECT       = (1 << 2)
 };
 
@@ -58,7 +62,8 @@
   const char *     name;       /* name found by builtin, printed by dumpdef */
   int              flags;      /* bitwise OR of M4_BUILTIN_* bits */
   unsigned int     min_args;   /* 0-based minimum number of arguments */
-  unsigned int     max_args;   /* max arguments, UINT_MAX if unlimited */
+  /* max arguments, UINT_MAX if unlimited; must be >= min_args */
+  unsigned int     max_args;
 };
 
 struct m4_macro




reply via email to

[Prev in Thread] Current Thread [Next in Thread]